-- Rune Use window handler
import "Turbine.UI.Lotro"
import "Vinny.Common"

local labelFont = Turbine.UI.Lotro.Font.TrajanPro14
local foreColor = Turbine.UI.Color( 0.9, 0.9, 0 )
local backColor = Turbine.UI.Color( 0, 0, 0.1 )
local greyColor = Turbine.UI.Color( 0.4, 0.4, 0.4 )
local Alias = Turbine.UI.Lotro.ShortcutType.Alias
local Button = Turbine.UI.Lotro.Button
local CheckBox = Turbine.UI.Lotro.CheckBox
local DropMenu = Vinny.Common.DropMenu
local Item = Turbine.UI.Lotro.ShortcutType.Item
local Label = Turbine.UI.Label
local Skill = Turbine.UI.Lotro.ShortcutType.Skill
local TextBox = Turbine.UI.Lotro.TextBox
local Left = Turbine.UI.ContentAlignment.MiddleLeft
local Center = Turbine.UI.ContentAlignment.MiddleCenter
local Right = Turbine.UI.ContentAlignment.MiddleRight
local Quickslot = Turbine.UI.Lotro.Quickslot
local Qsize = 36

RU_Window = class( Turbine.UI.Lotro.Window )

function RU_Window:AddField(control, text, pos, size)
	local field = control()
	field:SetParent( self )
	if text then field:SetText( text ) end
	field:SetPosition( pos.x,pos.y )
	field:SetSize( size.x,size.y )
	if control==Button or control==DropMenu or not text then return field end
	field:SetFont( labelFont )
	field:SetBackColor( backColor )
	field:SetForeColor( foreColor )
	field:SetTextAlignment( (control==TextBox or control==DropMenu) and Left or 
					control==Label and Right or Center )
	return field
end

---- This is the main Rune Use window
function RU_Window:Constructor()
	Turbine.UI.Lotro.Window.Constructor( self )
	self:SetText( "Rune Use" )
	self:SetSize( 220,220 )
--	self:SetBackColor( backColor )

	-- Position the window near the top and to left of center of the screen.
	local pos = RU_Settings.pos1 or 
            { x=Turbine.UI.Display.GetWidth()/5, y=self:GetHeight()/2 }
	self:SetPosition( pos.x, pos.y )

	self:AddField(Label, "Character Level:", {x=20,y=40}, {x=130,y=16} )
	self.level = self:AddField(TextBox, "", {x=160,y=41}, {x=30,y=15} )
	self.level:SetText(plevel)

	self:AddField(Label, "Enhancement limit:", {x=20,y=60}, {x=130,y=16} )
	self.el = self:AddField(TextBox, "", {x=160,y=61}, {x=30,y=15} )
	self.el:SetText(EL)

	self:AddField(Label, "Lowest tracery lvl:", {x=20,y=80}, {x=130,y=16} )
	self.lt = self:AddField(TextBox, "", {x=160,y=81}, {x=30,y=15} )
	if Pset then self.lt:SetText(Pset.lt) end

	-- Save button
	self.saveButton = self:AddField(Button, "Save settings", {x=55,y=105}, {x=104,y=20} )
    if not Pset then self.saveButton:SetEnabled( false ) end
	self.saveButton.Click = function( sender,args )
        local lt = tonumber(self.lt:GetText())
		if lt and lt<=EL and lt>50 then
			Pset.lt = lt
            Turbine.PluginData.Save(Turbine.DataScope.Server,"RU_Settings",RU_Settings)
            print("Tracery settings saved.")
		else printe("Invalid low level.") end
	end

	-- Create a Quickslot
	self:AddField(Label, "Drop Rune here:", {x=20,y=146}, {x=115,y=16} )
	self.Slot = self:AddField(Quickslot, nil, {x=145,y=135}, {x=Qsize,y=Qsize} )
	local Blank = self.Slot:GetShortcut()
	self.Slot:SetBackColor( Turbine.UI.Color( 0.2, 0.2, 0.2 ) )
	self.Slot.DragDrop = function( sender, args )
		local shortcut = sender:GetShortcut()
		local itemType = shortcut:GetType()
		if itemType==0 then return end
		if itemType~=2 then sender:SetShortcut(Blank) return end
		local item = shortcut:GetItem()
        local cat = item:GetCategory()
		local itemData = shortcut:GetData()
		if sender:IsAltKeyDown() then 
            print("Type="..itemType..", Cat="..cat..", Data="..itemData) 
        end
		if cat==ERC then
			RU_Item(itemData:sub(-5))
		else printe(item:GetName().." is not a rune item.") end
	end

	-- Inventory button
	self.bagButton = self:AddField(Button, "Check bags", {x=55,y=181}, {x=104,y=20} )
    if not Pset then self.saveButton:SetEnabled( false ) end
	self.bagButton.Click = function( sender,args )
		RU_Command:Execute("rub",'')
	end

end

RU_window = RU_Window()

-- Set Escape action
RU_window:SetWantsKeyEvents( true )
RU_window.KeyDown = function(sender, args)
	if( args.Action == Turbine.UI.Lotro.Action.Escape ) then
		RU_window:SetVisible( false )
	end
end
